==> ukui-menu_4.10.0.5.orig.tar.gz: ukui-menu-4.10.0.5/translations/ukui-menu_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>AppPageHeader</name>
    <message>
        <source>Search App</source>
        <translation>搜索应用</translation>
    </message>
</context>
<context>
    <name>FullScreenHeader</name>
    <message>
        <source>Contract</source>
        <translation>收缩</translation>
    </message>
</context>
<context>
    <name>LabelItem</name>
    <message>
        <source>Open the label selection interface</source>
        <translation type="vanished">打开标签选择界面</translation>
    </message>
</context>
<context>
    <name>PluginSelectMenu</name>
    <message>
        <source>Switch Sort Type</source>
        <translation>切换排序类型</translation>
    </message>
    <message>
        <source>Sort Type Options</source>
        <translation>排序类型选项</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Remove From Taskbar</source>
        <translation type="vanished">从任务栏移除</translation>
    </message>
    <message>
        <source>Add To Taskbar</source>
        <translation type="vanished">添加到任务栏</translation>
    </message>
    <message>
        <source>Add to desktop shortcuts</source>
        <translation>添加到桌面快捷方式</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
    <message>
        <source>Remove from folder</source>
        <translation>从应用组中移除</translation>
    </message>
    <message>
        <source>Add to folder</source>
        <translation>添加至应用组</translation>
    </message>
    <message>
        <source>Add to new folder</source>
        <translation>新建应用组</translation>
    </message>
    <message>
        <source>Dissolve folder</source>
        <translation>解散应用组</translation>
    </message>
    <message>
        <source>Add to &quot;%1&quot;</source>
        <translation>添加到 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Show ukui-menu.</source>
        <translation>显示开始菜单。</translation>
    </message>
    <message>
        <source>Quit ukui-menu.</source>
        <translation>退出开始菜单。</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Fix to favorite</source>
        <translation>固定到收藏</translation>
    </message>
    <message>
        <source>Remove from favorite</source>
        <translation>从收藏夹取消固定</translation>
    </message>
    <message>
        <source>Remove from taskbar</source>
        <translation>从任务栏取消固定</translation>
    </message>
    <message>
        <source>Add to taskbar</source>
        <translation>固定到任务栏</translation>
    </message>
    <message>
        <source>Fixed to all applications</source>
        <translation>固定到所有应用</translation>
    </message>
    <message>
        <source>Unfixed from all applications</source>
        <translation>从所有应用取消固定</translation>
    </message>
</context>
<context>
    <name>SearchInputBar</name>
    <message>
        <source>Search App</source>
        <translation>搜索应用</translation>
    </message>
</context>
<context>
    <name>Sidebar</name>
    <message>
        <source>Expand</source>
        <translation>展开</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AllAppDataProvider</name>
    <message>
        <source>All</source>
        <translation>所有应用</translation>
    </message>
    <message>
        <source>All applications</source>
        <translatorcomment>所有应用</translatorcomment>
        <translation>所有应用</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppCategoryPlugin</name>
    <message>
        <source>Category</source>
        <translatorcomment>功能排序</translatorcomment>
        <translation>功能排序</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>AudioVideo</source>
        <translation>音视频</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <source>Science</source>
        <translation>科学</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>实用程序</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
    <message>
        <source>Open Function Sort Menu</source>
        <translation>打开功能排序菜单</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppFolderHelper</name>
    <message>
        <source>New Folder %1</source>
        <translation>新文件夹 %1</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppLetterSortPlugin</name>
    <message>
        <source>Letter Sort</source>
        <translation>字母排序</translation>
    </message>
    <message>
        <source>Letter sort button</source>
        <translation type="vanished">字母排序按钮</translation>
    </message>
    <message>
        <source>Open Letter Sort Menu</source>
        <translation>打开字母排序菜单</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppSearchPlugin</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteExtension</name>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::PowerButton</name>
    <message>
        <source>power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation>锁定屏幕</translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>&lt;p&gt;The computer remains on but consumes less power, and the applications will remain open. You can quickly wake up the computer and return to the state you left&lt;/p&gt;</source>
        <translation>&lt;p&gt;电脑保持开机状态，但耗电较少。应用会一直保持打开状态，可快速唤醒电脑并恢复到你离开的状态&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;The current user logs out of the system, ending their session and returning to the login screen&lt;/p&gt;</source>
        <translation>&lt;p&gt;当前用户从系统中注销，结束其会话并返回登录界面&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, turn off the computer, and then turn it back on&lt;/p&gt;</source>
        <translation>&lt;p&gt;关闭所有应用，关闭电脑，然后重新打开电脑&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, and then turn off the computer&lt;/p&gt;</source>
        <translation>&lt;p&gt;关闭所有应用，然后关闭电脑&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Turn off the computer, but the applications will remain open. When you turn on the computer again, you can return to the state you were in before&lt;/p&gt;</source>
        <translation>&lt;p&gt;关闭电脑，但是应用会一直保持打开状态。当打开电脑时，可以恢复到你离开的状态&lt;/p&gt;</translation>
    </message>
</context>
</TS>

==> ukui-menu_4.20.2.2.orig.tar.gz: ukui-menu-4.20.2.2/translations/ukui-menu_zh_CN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_CN">
<context>
    <name>EditText</name>
    <message>
        <source>Folder</source>
        <translation>应用组</translation>
    </message>
</context>
<context>
    <name>FavoriteExtension</name>
    <message>
        <source>Enable editing mode</source>
        <translation>启用批量编辑模式</translation>
    </message>
    <message>
        <source>Remove all favorite apps</source>
        <translation>解除所有已收藏应用</translation>
    </message>
</context>
<context>
    <name>FolderGridView</name>
    <message>
        <source>Folder</source>
        <translation>应用组</translation>
    </message>
</context>
<context>
    <name>FullScreenAppList</name>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Enable editing mode</source>
        <translation>启用批量编辑模式</translation>
    </message>
    <message>
        <source>Remove all favorite apps</source>
        <translation>解除所有已收藏应用</translation>
    </message>
    <message>
        <source>All Applications</source>
        <translation>全部应用</translation>
    </message>
</context>
<context>
    <name>FullScreenHeader</name>
    <message>
        <source>Contract</source>
        <translation>收缩</translation>
    </message>
</context>
<context>
    <name>PluginSelectButton</name>
    <message>
        <source>Letter Sort</source>
        <translation>字母排序</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>功能排序</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Add to desktop shortcuts</source>
        <translation>添加到桌面快捷方式</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>卸载</translation>
    </message>
    <message>
        <source>Remove from folder</source>
        <translation>从应用组中移除</translation>
    </message>
    <message>
        <source>Add to folder</source>
        <translation>添加至应用组</translation>
    </message>
    <message>
        <source>Dissolve folder</source>
        <translation>解散应用组</translation>
    </message>
    <message>
        <source>Add to &quot;%1&quot;</source>
        <translation>添加到 &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Show ukui-menu.</source>
        <translation>显示开始菜单。</translation>
    </message>
    <message>
        <source>Quit ukui-menu.</source>
        <translation>退出开始菜单。</translation>
    </message>
    <message>
        <source>Fix to favorite</source>
        <translation>固定到收藏</translation>
    </message>
    <message>
        <source>Remove from favorite</source>
        <translation>从收藏夹取消固定</translation>
    </message>
    <message>
        <source>Remove from taskbar</source>
        <translation>从任务栏取消固定</translation>
    </message>
    <message>
        <source>Add to taskbar</source>
        <translation>固定到任务栏</translation>
    </message>
    <message>
        <source>Fixed to all applications</source>
        <translation>固定到所有应用</translation>
    </message>
    <message>
        <source>Unfixed from all applications</source>
        <translation>从所有应用取消固定</translation>
    </message>
    <message>
        <source>Create a new folder</source>
        <translation>新建应用组</translation>
    </message>
    <message>
        <source>Remove from List</source>
        <translation>从列表中删除</translation>
    </message>
</context>
<context>
    <name>SearchInputBar</name>
    <message>
        <source>Search App</source>
        <translation>搜索应用</translation>
    </message>
</context>
<context>
    <name>Sidebar</name>
    <message>
        <source>Expand</source>
        <translation>展开</translation>
    </message>
    <message>
        <source>Contract</source>
        <translation>收缩</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>计算机</translation>
    </message>
    <message>
        <source>Control center</source>
        <translation>控制面板</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AllAppDataProvider</name>
    <message>
        <source>All</source>
        <translation>所有应用</translation>
    </message>
    <message>
        <source>All applications</source>
        <translatorcomment>所有应用</translatorcomment>
        <translation>所有应用</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppCategoryModel</name>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>AudioVideo</source>
        <translation>音视频</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <source>Science</source>
        <translation>科学</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>实用程序</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppCategoryPlugin</name>
    <message>
        <source>Category</source>
        <translatorcomment>功能排序</translatorcomment>
        <translation>功能排序</translation>
    </message>
    <message>
        <source>Audio</source>
        <translation>音频</translation>
    </message>
    <message>
        <source>AudioVideo</source>
        <translation>音视频</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>开发</translation>
    </message>
    <message>
        <source>Education</source>
        <translation>教育</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>游戏</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>图形</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>网络</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>办公</translation>
    </message>
    <message>
        <source>Science</source>
        <translation>科学</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>设置</translation>
    </message>
    <message>
        <source>System</source>
        <translation>系统</translation>
    </message>
    <message>
        <source>Utility</source>
        <translation>实用程序</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>视频</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>其他</translation>
    </message>
    <message>
        <source>Open Function Sort Menu</source>
        <translation>打开功能排序菜单</translation>
    </message>
    <message>
        <source>Letter Sort</source>
        <translation>字母排序</translation>
    </message>
    <message>
        <source>Recently Installed</source>
        <translation>最新安装</translation>
    </message>
    <message>
        <source>All Applications</source>
        <translation>全部应用</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppFolderHelper</name>
    <message>
        <source>New Folder %1</source>
        <translation>新文件夹 %1</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppLetterSortPlugin</name>
    <message>
        <source>Letter Sort</source>
        <translation>字母排序</translation>
    </message>
    <message>
        <source>Open Letter Sort Menu</source>
        <translation>打开字母排序菜单</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::AppSearchPlugin</name>
    <message>
        <source>Search</source>
        <translation>搜索</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteExtension</name>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteFolderHelper</name>
    <message>
        <source>New Folder %1</source>
        <translation>应用组 %1</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::FavoriteWidget</name>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>favorite</source>
        <translation>收藏</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::PowerButton</name>
    <message>
        <source>power</source>
        <translation>电源</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>切换用户</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>休眠</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>睡眠</translation>
    </message>
    <message>
        <source>Lock Screen</source>
        <translation>锁定屏幕</translation>
    </message>
    <message>
        <source>Log Out</source>
        <translation>注销</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>重启</translation>
    </message>
    <message>
        <source>Power Off</source>
        <translation>关机</translation>
    </message>
    <message>
        <source>&lt;p&gt;The computer remains on but consumes less power, and the applications will remain open. You can quickly wake up the computer and return to the state you left&lt;/p&gt;</source>
        <translation>&lt;p&gt;电脑保持开机状态，但耗电较少。应用会一直保持打开状态，可快速唤醒电脑并恢复到你离开的状态&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;The current user logs out of the system, ending their session and returning to the login screen&lt;/p&gt;</source>
        <translation>&lt;p&gt;当前用户从系统中注销，结束其会话并返回登录界面&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, turn off the computer, and then turn it back on&lt;/p&gt;</source>
        <translation>&lt;p&gt;关闭所有应用，关闭电脑，然后重新打开电脑&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Close all applications, and then turn off the computer&lt;/p&gt;</source>
        <translation>&lt;p&gt;关闭所有应用，然后关闭电脑&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;Turn off the computer, but the applications will remain open. When you turn on the computer again, you can return to the state you were in before&lt;/p&gt;</source>
        <translation>&lt;p&gt;关闭电脑，但是应用会一直保持打开状态。当打开电脑时，可以恢复到你离开的状态&lt;/p&gt;</translation>
    </message>
</context>
<context>
    <name>UkuiMenu::RecentlyInstalledModel</name>
    <message>
        <source>Recently Installed</source>
        <translation>最新安装</translation>
    </message>
</context>
</TS>
